@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# (C) Copyright 2010-2023 MET Norway
+# (C) Copyright 2010-2025 MET Norway
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,9 +32,6 @@ use constant DEFAULT_TABLE_FORMAT => 'BUFRDC';
 # Will be used if neither --tablepath nor $ENV{BUFR_TABLES} is set
 use constant DEFAULT_TABLE_PATH_BUFRDC => '/usr/local/lib/bufrtables';
 use constant DEFAULT_TABLE_PATH_ECCODES => '/usr/local/share/eccodes/definitions/bufr/tables';
-# Ought to be your most up-to-date B table
-use constant DEFAULT_TABLE_BUFRDC => 'B0000000000000039000';
-use constant DEFAULT_TABLE_ECCODES => '0/wmo/39';
 
 # Parse command line options
 my %option = ();
@@ -111,8 +108,7 @@ if ($option{tablepath}) {
 }
 
 # BUFR table file to use
-my $table = $option{bufrtable} ||
-    ($tableformat eq 'BUFRDC' ? DEFAULT_TABLE_BUFRDC : DEFAULT_TABLE_ECCODES);
+my $table = $option{bufrtable} || Geo::BUFR->get_max_table_version();
 
 my $bufr = Geo::BUFR->new();
 
@@ -249,6 +245,6 @@ Pål Sannes E<lt>pal.sannes@met.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2010-2023 MET Norway
+Copyright (C) 2010-2025 MET Norway
 
 =cut
